@@ -1,8 +1,8 @@
 import os
 import copy
 import tempfile
-import atexit
 import shutil
+import warnings
 import yaml
 from lume.serializers.base import SerializerBase
 from lume.serializers.hdf5 import HDF5Serializer
@@ -585,20 +585,16 @@ class CommandWrapper(Base):
         cleanup : bool
             Whether or not to remove the directory at exit. Defaults to True.
         """
+        
+        if not cleanup:
+             warnings.warn("cleanup option has been removed", DeprecationWarning)
+        
         # Set paths
         if self._use_temp_dir:
             # Need to attach this to the object. Otherwise it will go out of scope.
             self._tempdir = tempfile.TemporaryDirectory(dir=workdir)
             self._base_path = self._tempdir.name
-            if cleanup:
-                atexit.register(self._cleanup_workdir)
+
         else:
             # Work in place
             self._base_path = self.original_path
-
-    def _cleanup_workdir(self):
-        if self._tempdir:
-            try:
-                self._tempdir.cleanup()
-            except OSError:
-                shutil.rmtree(self._tempdir.name, ignore_errors=True)
